@@ -4,7 +4,7 @@ from .buffer import Buffer
 from .builder import HOOKS, build_dataloader, build_hook
 from .comm import (all_gather, broadcast, gather, get_dist_info, get_rank,
                    get_world_size, init_dist, is_distributed, is_elastic,
-                   is_main_process, is_slurm, master_only, synchronize)
+                   is_main_process, is_slurm, main_only, sync)
 from .engine import Engine
 from .hooks import (CheckpointHook, ClosureHook, CommandLineWriter,
                     EmptyCacheHook, EvalHook, EventWriterHook, Hook,
@@ -17,7 +17,7 @@ __all__ = [
     'Buffer', 'HOOKS', 'build_dataloader', 'build_hook', 'all_gather',
     'broadcast', 'gather', 'get_dist_info', 'get_rank', 'get_world_size',
     'init_dist', 'is_distributed', 'is_elastic', 'is_main_process', 'is_slurm',
-    'master_only', 'synchronize', 'Engine', 'CheckpointHook', 'ClosureHook',
+    'main_only', 'sync', 'Engine', 'CheckpointHook', 'ClosureHook',
     'CommandLineWriter', 'EmptyCacheHook', 'EvalHook', 'EventWriterHook',
     'Hook', 'JSONWriter', 'LrUpdaterHook', 'OptimizerHook', 'PreciseBNHook',
     'SamplerSeedHook', 'TensorboardWriter', 'TimerHook',
