@@ -11,17 +11,17 @@ _COLOR_SPACES = {
 }
 
 
-def imread(filename, flag='color', to_rgb=True):
+def imread(filename, flag='color', to_rgb=False):
     """
     Read an image from a file.
 
     Args:
         filename (str): Path to the image file.
-        flag (str or int, optional): Flags specifying the color type of the
-            loaded image. Currently supported flags include ``'color'``,
-            ``'grayscale'`` and ``'unchanged'``. Default: ``'color'``.
+        flag (str | int, optional): Flags specifying the color type of the
+            loaded image. Currently supported flags include ``color``,
+            ``grayscale``, and ``unchanged``. Default: ``color``.
         to_rgb (bool, optional): Whether to convert channel order from ``BGR``
-            to ``RGB``. Default: ``True``.
+            to ``RGB``. Default: ``False``.
 
     Returns:
         :obj:`np.ndarray`: The loaded image array.
@@ -41,18 +41,24 @@ def imread(filename, flag='color', to_rgb=True):
     return img
 
 
-def imwrite(img, filename, params=None):
+def imwrite(img, filename, overwrite=True, params=None):
     """
     Write an image to a file.
 
     Args:
         img (:obj:`np.ndarray`): The image array to be written.
         filename (str): Path to the image file.
-        params (list or None, optional): Same as the :obj:`cv2.imwrite`
+        params (list | None, optional): Same as the :obj:`cv2.imwrite`
             interface. Default: ``None``.
 
     Returns:
         bool: Successful or not.
     """
+    if nncore.is_file(filename):
+        if overwrite:
+            nncore.remove(filename)
+        else:
+            raise FileExistsError("file '{}' exists".format(filename))
+
     nncore.mkdir(nncore.dir_name(nncore.abs_path(filename)))
     return cv2.imwrite(filename, img, params)
