@@ -3,7 +3,6 @@
 import torch.nn as nn
 
 from nncore import Registry, build_object
-from nncore.engine import comm
 from nncore.parallel import NNDataParallel, NNDistributedDataParallel
 from .bundle import ModuleList, Sequential
 
@@ -16,7 +15,7 @@ LOSSES = Registry('loss', parent=MODELS)
 MODULES = Registry('module', parent=MODELS)
 
 
-def build_model(cfg, *args, bundler=None, wrapper=None, **kwargs):
+def build_model(cfg, *args, bundler=None, dist=None, **kwargs):
     """
     Build a general model from a dict or str. This method searches for modules
     in :obj:`MODELS` first, and then fall back to :obj:`torch.nn`.
@@ -26,37 +25,32 @@ def build_model(cfg, *args, bundler=None, wrapper=None, **kwargs):
         bundler (str | None, optional): The type of bundler for multiple
             models. Expected values include ``'sequential'``, ``'modulelist'``,
             and ``None``. Default: ``None``.
-        wrapper (str | None, optional): The type of wrapper for the model.
-            Expected values include ``'dp'``, ``'ddp'``, and ``None``. Default:
-            ``None``.
+        dist (bool | None, optional): Whether the model is distributed. If not
+            specified, the model will not be wrapped. Default: ``None``.
 
     Returns:
         :obj:`nn.Module`: The constructed model.
     """
     assert bundler in ('sequential', 'modulelist', None)
-    assert wrapper in ('dp', 'ddp', None)
 
-    obj = build_object(cfg, [MODELS, nn], args=args, **kwargs)
+    model = build_object(cfg, [MODELS, nn], args=args, **kwargs)
 
-    if isinstance(obj, (list, tuple)):
-        obj = [o for o in obj if o is not None]
-        if bundler == 'sequential' and len(obj) > 1:
-            obj = Sequential(obj)
-    elif obj is None:
+    if isinstance(model, (list, tuple)):
+        model = [m for m in model if m is not None]
+        if bundler == 'sequential' and len(model) > 1:
+            model = Sequential(model)
+    elif model is None:
         return
 
     if bundler == 'modulelist':
-        obj = ModuleList(obj)
+        model = ModuleList(model)
 
-    if wrapper == 'auto':
-        wrapper = 'ddp' if comm.is_distributed() else 'dp'
+    if dist:
+        model = NNDistributedDataParallel(model)
+    elif dist is not None:
+        model = NNDataParallel(model)
 
-    if wrapper == 'dp':
-        obj = NNDataParallel(obj)
-    elif wrapper == 'ddp':
-        obj = NNDistributedDataParallel(obj)
-
-    return obj
+    return model
 
 
 def build_act_layer(cfg, *args, **kwargs):
