@@ -2,7 +2,7 @@
 
 from .collate import collate
 from .container import DataContainer
-from .data_parallel import NNDataParallel, NNDistributedDataParallel
+from .parallel import NNDataParallel, NNDistributedDataParallel
 
 __all__ = [
     'collate', 'DataContainer', 'NNDataParallel', 'NNDistributedDataParallel'
