@@ -59,7 +59,7 @@ def collate(batch, samples_per_gpu=-1):
             stack=batch[0].stack,
             pad_value=batch[0].pad_value,
             pad_dims=batch[0].pad_dims,
-            to_gpu=batch[0].to_gpu)
+            cpu_only=batch[0].cpu_only)
     elif isinstance(batch[0], list):
         return collate(nncore.concat(batch), samples_per_gpu)
     elif isinstance(batch[0], tuple):
