@@ -185,6 +185,7 @@ class CfgNode(OrderedDict):
 
             if isinstance(value, dict):
                 refine = value.pop('_refine_', None)
+                repeat = value.pop('_repeat_', None)
                 delete = value.pop('_delete_', None)
                 insert = value.pop('_insert_', None)
                 update = value.pop('_update_', None)
@@ -195,6 +196,10 @@ class CfgNode(OrderedDict):
                 if key not in self and refine:
                     continue
 
+                if key in self and isinstance(repeat, int):
+                    self[key] = [self[key] for _ in range(repeat)]
+                    continue
+
                 if key in self and isinstance(self[key], dict):
                     assert not do_update and not (delete and do_insert)
                     if do_insert:
