@@ -5,7 +5,7 @@ import sys
 
 from termcolor import colored
 
-import nncore
+from .path import abs_path, dir_name, mkdir
 
 _COLOR_MAP = {
     0: 'white',
@@ -43,14 +43,14 @@ def get_logger(logger_or_name=None,
     ``0``, a :obj:`FileHandler` will also be added.
 
     Args:
-        logger_or_name (:obj:`logging.Logger` or str or None, optional): The
+        logger_or_name (:obj:`logging.Logger` | str | None, optional): The
             logger or name of the logger. Default: ``None``.
         fmt (str, optional): Logging format of the logger. The format must end
             with ``'%(message)s'`` to make sure that the colors can be rendered
             properly. Default: ``'[%(asctime)s %(levelname)s]: %(message)s'``.
         datefmt (str, optional): Date format of the logger. Default:
             ``'%Y-%m-%d %H:%M:%S'``.
-        log_level (str or int, optional): Log level of the logger. Note that
+        log_level (str | int, optional): Log level of the logger. Note that
             only the main process (rank 0) is affected, and other processes
             will set the level to ``ERROR`` thus be silent at most of the time.
             Default: :obj:`logging.INFO`.
@@ -91,7 +91,7 @@ def get_logger(logger_or_name=None,
         pass
 
     if log_file is not None:
-        nncore.mkdir(nncore.dir_name(nncore.abs_path(log_file)))
+        mkdir(dir_name(abs_path(log_file)))
         fh = logging.FileHandler(log_file, mode='w')
         formatter = logging.Formatter(fmt=fmt, datefmt=datefmt)
         fh.setFormatter(formatter)
@@ -102,14 +102,14 @@ def get_logger(logger_or_name=None,
 
 def log_or_print(msg, logger_or_name=None, log_level=logging.INFO, **kwargs):
     """
-    Print a message with a potential logger. If ``logger`` is a valid
+    Print a message with a logger. If ``logger`` is a valid
     :obj:`logging.Logger` or a name of the logger, then it would be used.
     Otherwise this method will use the normal :obj:`print` function instead.
 
     Args:
         msg (str): The message to be logged.
-        logger_or_name (:obj:`logging.Logger` or str or None, optional): The
-            potential logger or name of the logger to use. Default: ``None``.
+        logger_or_name (:obj:`logging.Logger` | str | None, optional): The
+            logger or name of the logger to use. Default: ``None``.
         log_level (int, optional): Log level of the logger. Default:
             :obj:`logging.INFO`.
     """
